==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Η εγγραφή βίντεο είναι σε εξέλιξη. Να κλείσει το παράθυρο;</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Δεν έχετε άδεια πρόσβασης στον φάκελο</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Μη έγκυρος φάκελος</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Βασικό</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Τοποθεσία φακέλου</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Γρήγορη λειτουργία</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Χρονοκαθυστέρηση</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Φορμά Εξόδου</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 τμχ</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 τμχ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Το Camera είναι ένα εργαλείο λήψης και εγγραφής φωτογραφιών και βίντεο, με τη χρήση της κάμερας του υπολογιστή σας.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Το αρχείο δεν αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Αποθήκευση σε:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Φωτογραφία:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Βίντεο:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ρυθμίσεις ανάλυσεις</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Ανάλυση:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Λήξη εγγραφής</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Ακύρωση λήψης φωτογραφιών</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Λήψη φωτογραφίας</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Εγγραφή βίντεο</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Ακύρωση λήψης φωτογραφιών</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">Κανένα</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Δεν βρέθηκε κάμερα</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Η κάμερα είναι σε χρήση</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Λήξη εγγραφής</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Η εγγραφή βίντεο είναι σε εξέλιξη. Να κλείσει το παράθυρο;</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Δεν έχετε άδεια πρόσβασης στον φάκελο</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Μη έγκυρος φάκελος</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Βασικό</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Τοποθεσία φακέλου</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Γρήγορη λειτουργία</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Χρονοκαθυστέρηση</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Φορμά Εξόδου</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 τμχ</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 τμχ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Το Camera είναι ένα εργαλείο λήψης και εγγραφής φωτογραφιών και βίντεο, με τη χρήση της κάμερας του υπολογιστή σας.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Το αρχείο δεν αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Αποθήκευση σε:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Φωτογραφία:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Βίντεο:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ρυθμίσεις ανάλυσεις</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Ανάλυση:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound effects</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Λήξη εγγραφής</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Ακύρωση λήψης φωτογραφιών</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Λήψη φωτογραφίας</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Εγγραφή βίντεο</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Ακύρωση λήψης φωτογραφιών</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Δεν βρέθηκε κάμερα</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Η κάμερα είναι σε χρήση</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Λήξη εγγραφής</translation>
    </message>
</context>
</TS>
